@@ -1,13 +1,13 @@
 <?php
-/* $Id: catalan-utf-8.inc.php,v 2.77.2.1 2005/04/08 16:58:12 lem9 Exp $ */
+/* $Id: catalan-utf-8.inc.php,v 2.82.2.1 2005/06/30 19:06:31 lem9 Exp $ */
 
 $charset = 'utf-8';
 $allow_recoding = TRUE;
 $text_dir = 'ltr';
 $left_font_family = 'verdana, arial, helvetica, geneva, sans-serif';
 $right_font_family = 'arial, helvetica, geneva, sans-serif';
-$number_thousands_separator = ',';
-$number_decimal_separator = '.';
+$number_thousands_separator = '.';
+$number_decimal_separator = ',';
 // abreviatures de Byte, Kilo, Mega, Giga, Tera, Peta, Exa
 $byteUnits = array('Bytes', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');
 $timespanfmt = '%s dies, %s hores, %s minuts i %s segons';
@@ -46,7 +46,7 @@ $strAdministration = 'Administració';
 $strAffectedRows = 'Files afectades:';
 $strAfter = 'Després %s';
 $strAfterInsertBack = 'Tornar';
-$strAfterInsertNewInsert = 'Inserta un nou registre';
+$strAfterInsertNewInsert = 'Insereix un nou registre';
 $strAfterInsertNext = 'Editar el següent registre'; 
 $strAfterInsertSame = 'Tornar a aquesta plana';
 $strAll = 'Tot';
@@ -81,20 +81,20 @@ $strBinLogServerId = 'ID de Servidor';
 $strBinary = ' Binari ';
 $strBinaryDoNotEdit = ' Binari - no editeu ';
 $strBinaryLog = 'Registre binari';
-$strBookmarkAllUsers = 'Deixa accedir a cada usuari a aquesta consulta arxivada';
-$strBookmarkDeleted = 'S\'ha esborrat la consulta arxivada.';
+$strBookmarkAllUsers = 'Deixar accedir a cada usuari a aquesta consulta desada';
+$strBookmarkDeleted = 'S\'ha esborrat la consulta desada.';
 $strBookmarkLabel = 'Etiqueta';
-$strBookmarkOptions = 'Opcions de consulta arxivada';
-$strBookmarkQuery = 'Consulta SQL arxivada';
-$strBookmarkThis = 'Arxiva aquesta consulta SQL';
+$strBookmarkOptions = 'Opcions de consulta desada';
+$strBookmarkQuery = 'Consulta SQL desada';
+$strBookmarkThis = 'Desa aquesta consulta SQL';
 $strBookmarkView = 'Només mirar';
 $strBrowse = 'Navega';
 $strBrowseForeignValues = 'Navega valors externs';
-$strBufferPool = 'Grup de memòries intermèdies';
-$strBufferPoolUsage = 'Ús del grup de memòries intermèdies';
+$strBufferPool = 'Grup de memòries intermitges';
+$strBufferPoolUsage = 'Ús del grup de memòries intermitges';
 $strBulgarian = 'Búlgar';
 $strBusyPages = 'Planes ocupades';
-$strBzError = 'phpMyAdmin és incapaç de comprimir el volcat degut a una extensió Bz2 incorrecta en aquesta versió de php. És molt recomenable posar a la directiva <code>$cfg[\'BZipDump\']</code> el valor <code>FALSE</code> al fitxer de configuració de phpMyAdmin. Si vol utilitzar les facilitats de compresió Bz2, és necessari actualitzar el php a la darrera versió disponible. Es pot consultar el informe d\'errada %s de php per a més detalls.';
+$strBzError = 'phpMyAdmin és incapaç de comprimir el volcat degut a una extensió Bz2 incorrecta en aquesta versió de php. És molt recomenable posar a la directiva <code>$cfg[\'BZipDump\']</code> el valor <code>FALSE</code> al fitxer de configuració de phpMyAdmin. Si vols utilitzar les facilitats de compresió Bz2, és necessari actualitzar el php a la darrera versió disponible. Es pot consultar el informe d\'errada %s de php per a més detalls.';
 $strBzip = '"comprimit amb bzip"';
 
 $strCSVOptions = 'Opcions CSV';
@@ -123,7 +123,7 @@ $strCharsetOfFile = 'Joc de caràcters de l\'arxiu:';
 $strCharsets = 'Jocs de caracters';
 $strCharsetsAndCollations = 'Jocs de Caracters i ordenacions';
 $strCheckAll = 'Verificar-ho tot';
-$strCheckOverhead = 'Comprovar taules defragmentades';
+$strCheckOverhead = 'Comprovar taules desfragmentades';
 $strCheckPrivs = 'Comprova els Permissos';
 $strCheckPrivsLong = 'Comprova els Permissos per la Base de dades &quot;%s&quot;.';
 $strCheckTable = 'Verifica la taula';
@@ -145,12 +145,14 @@ $strConnections = 'Connexions';
 $strConstraintsForDumped = 'Restriccions per taules volcades';
 $strConstraintsForTable = 'Restriccions per la taula';
 $strCookiesRequired = 'A partir d\'aquest punt és necessari tenir les galetes (cookies) activades.';
+$strCopy = 'Copiar'; 
 $strCopyDatabaseOK = 'La Base de dades %s s\'ha copiat a %s';
 $strCopyTable = 'Copia taula a (base-de-dades<b>.</b>taula):';
-$strCopyTableOK = 'La taula %s ha estat copiada a %s.';
+$strCopyTableOK = 'La taula %s s\'ha copiat a %s.';
 $strCopyTableSameNames = 'No es pot copiar la taula sobre ella mateixa';
 $strCouldNotKill = 'phpMyAdmin no pot cancel.lar el fil %s. Probablement, ja és tancat.';
 $strCreate = 'Crear';
+$strCreateDatabaseBeforeCopying = 'CREATE DATABASE abans de copiar';
 $strCreateIndex = 'Crea un índex a la columna:&nbsp;%s';
 $strCreateIndexTopic = 'Crea un nou índex';
 $strCreateNewDatabase = 'Crea una nova base de dades';
@@ -245,11 +247,11 @@ $strEngines = 'Motors';
 $strEnglish = 'Anglès';
 $strEnglishPrivileges = ' Nota: Els noms dels privilegis del MySQL són en llengua anglesa ';
 $strError = 'Errada';
-$strEscapeWildcards = 'Els comodins _ i % han de marcar-se amb una \ per usar-las literalment';
+$strEscapeWildcards = 'Els comodins _ i % han de marcar-se amb una \ per usar-los literalment';
 $strEstonian = 'Estonià ';
 $strExcelEdition = 'Edició per Excel';
 $strExcelOptions = 'Opcions d\'Excel';
-$strExecuteBookmarked = 'Executa una consulta arxivada';
+$strExecuteBookmarked = 'Executa una consulta desada';
 $strExplain = 'Explicació de l\'SQL';
 $strExport = 'Exportar';
 $strExtendedInserts = 'Insercions ampliades';
@@ -263,7 +265,7 @@ $strFieldsEmpty = ' El comptador de camps és buit! ';
 $strFieldsEnclosedBy = 'Camps englobats per';
 $strFieldsEscapedBy = 'Camps amb marca d\'escapada';
 $strFieldsTerminatedBy = 'Camps acabats per';
-$strFileAlreadyExists = 'L\'arxiu %s ja existeix al servidor, canvia el nom o marca la opció de sobreescriure.';
+$strFileAlreadyExists = 'L\'arxiu %s ja existeix al servidor, canvia el nom o marca l\'opció de sobreescriure.';
 $strFileCouldNotBeRead = 'No es pot llegir el fitxer';
 $strFileNameTemplate = 'Nom de fitxer de plantilla';
 $strFileNameTemplateHelp = 'Utilitza __DB__ per a nom de base de dades, __TABLE__ per a nom de taula i opcions %sany strftime%s per especificacions horaries, la extensió s\'afegirà automàgicament. Qualsevol altre text es mantindrà.';
@@ -280,6 +282,8 @@ $strFunction = 'Funció';
 $strGenBy = 'Generat per';
 $strGenTime = 'Temps de generació';
 $strGeneralRelationFeat = 'Característiques generals de relacions';
+$strGenerate = 'Generar'; 
+$strGeneratePassword = 'Generar Contrasenya'; 
 $strGeorgian = 'Georgià';
 $strGerman = 'Alemany';
 $strGlobal = 'global';
@@ -364,8 +368,8 @@ $strLatvian = 'Letó';
 $strLengthSet = 'Longitud/Valors*';
 $strLimitNumRows = 'registres per plana';
 $strLineFeed = 'Salt de línia: \\n';
-$strLinesTerminatedBy = 'Línies terminades per';
-$strLinkNotFound = 'L\'enllaç no s\'ha trobat';
+$strLinesTerminatedBy = 'Línies acabades amb';
+$strLinkNotFound = 'No s\'ha trobat l\'enllaç ';
 $strLinksTo = 'Enllaços a';
 $strLithuanian = 'Lituà ';
 $strLoadExplanation = 'El millor metode es comprova per defecte, pero es pot canviar si falla.';
@@ -508,13 +512,19 @@ $strPrintView = 'Imprimir vista';
 $strPrintViewFull = 'Vista d\'impresió (amb texts sencers)';
 $strPrivDescAllPrivileges = 'Inclou tots els permissos excepte GRANT (atorgar).';
 $strPrivDescAlter = 'Permet alterar l\'estructura de taules existents.';
+$strPrivDescAlterDb = 'Permet alterar l\'estructura de taules existents així com canviar el joc de caracters i ordenacions de les bases de dades.'; 
+$strPrivDescAlterRoutine = 'Permet alterar i esborrar rutines enmagatzemades.'; 
 $strPrivDescCreateDb = 'Permet crear noves bases de dades i taules.';
+$strPrivDescCreateRoutine = 'Permet crear rutines enmgatzemades.';  
 $strPrivDescCreateTbl = 'Permet crear noves taules.';
 $strPrivDescCreateTmpTable = 'Permet crear taules temporals.';
+$strPrivDescCreateUser = 'Permet crear, esborrar i reanomenar comptes d\'usuari.'; 
+$strPrivDescCreateView = 'Permet crear noves vistes.';  
 $strPrivDescDelete = 'Permet esborrar dades.';
 $strPrivDescDropDb = 'Permet eliminar bases de dades i taules.';
 $strPrivDescDropTbl = 'Permet eliminar taules.';
 $strPrivDescExecute = 'Permet executar processos enmagatzemats (stored procedures); No té efecte en aquesta versió de MySQL.';
+$strPrivDescExecute5 = 'Permet executar rutines enmagatzemades.'; 
 $strPrivDescFile = 'Permet importar i exportar dades amb fitxers externs.';
 $strPrivDescGrant = 'Permet afegir usuaris i permissos sense tenir que recarregar les taules de permissos.';
 $strPrivDescIndex = 'Permet crear i eliminar indexos.';
@@ -531,6 +541,7 @@ $strPrivDescReplClient = 'Dona el dret a l\'usuari de preguntar quins servidors
 $strPrivDescReplSlave = 'Es necessari per a la replicació en servidors esclaus.';
 $strPrivDescSelect = 'Permet llegir dades.';
 $strPrivDescShowDb = 'Dona accés a la llista completa de bases de dades.';
+$strPrivDescShowView = 'Permet fer consultes de tipus SHOW CREATE VIEW.'; 
 $strPrivDescShutdown = 'Permet parar el servidor.';
 $strPrivDescSuper = 'Permet connectar, encara que s\'hagi arribat al máxim numero de connexions permés; Es necessari per moltes operacions d\'administració com ara establir variables globals o bé cancel.lar fils d\'execució d\'altres usuaris.';
 $strPrivDescUpdate = 'Permet canviar dades.';
@@ -579,6 +590,7 @@ $strRevokeAndDelete = 'Denega tots els permissos actius dels usuaris i els esbor
 $strRevokeAndDeleteDescr = 'Els usuaris encara tindran el permís USAGE fins que es recarreguin els permissos.';
 $strRevokeMessage = 'Has tret els permissos per %s';
 $strRomanian = 'Romanés';
+$strRoutines = 'Rutines'; 
 $strRowLength = 'Longitud de fila';
 $strRowSize = 'Mida de fila ';
 $strRows = 'Fila';
@@ -713,6 +725,7 @@ $strTraditionalChinese = 'Xinés Tradicional';
 $strTraditionalSpanish = 'Espanyol Tradicional';
 $strTraffic = 'Tràfic';
 $strTransformation_application_octetstream__download = 'Mostra un enllaç per descarregar les dades binàries d\'un camp. La primera dada és el nom d\'arxiu binari. La segona dada és un possible nom de camp d\'una taula que contingui el nom d\'arxiu. Si es facilita la segona dada és necessari tenir la primera dada buida';
+$strTransformation_application_octetstream__hex = 'Mostra la representació hexadecimal de les dades.'; 
 $strTransformation_image_jpeg__inline = 'Mostra una miniatura am enllaç; opcions: ample,alt en pixels (respecta la proporció original)';
 $strTransformation_image_jpeg__link = 'Es mostra com a enllaç a la imatge.';
 $strTransformation_image_png__inline = 'Veure image/jpeg: en linia';
