@@ -1,5 +1,5 @@
 <?php
-/* $Id: czech-windows-1250.inc.php,v 2.92 2005/03/30 19:21:10 lem9 Exp $ */
+/* $Id: czech-windows-1250.inc.php,v 2.98.2.1 2005/06/30 17:22:38 lem9 Exp $ */
 
 /**
  * Czech language file by
@@ -155,10 +155,12 @@ $strConstraintsForDumped = 'Omezen pro exportovan tabulky';
 $strConstraintsForTable = 'Omezen pro tabulku';
 $strCookiesRequired = 'Bhem tohoto kroku muste mt povoleny cookies.';
 $strCopyDatabaseOK = 'Databze %s byla zkoprovna na %s';
+$strCopy = 'Koprovat';
 $strCopyTable = 'Koprovat tabulku do (databze<b>.</b>tabulka):';
 $strCopyTableOK = 'Tabulka %s byla zkoprovna do %s.';
 $strCopyTableSameNames = 'Nelze koprovat tabulku na sebe samu!';
 $strCouldNotKill = 'phpMyAdminovi se nepodailo ukonit vlkno %s. Pravdpodobn jeho bh ji skonil.';
+$strCreateDatabaseBeforeCopying = 'Vytvoit databzi ped koprovnm (CREATE DATABASE)';
 $strCreateIndexTopic = 'Vytvoit nov index';
 $strCreateIndex = 'Vytvoit index na&nbsp;%s&nbsp;sloupcch';
 $strCreateNewDatabase = 'Vytvoit novou databzi';
@@ -289,6 +291,8 @@ $strFunction = 'Funkce';
 
 $strGenBy = 'Vygeneroval';
 $strGeneralRelationFeat = 'Obecn funkce relac';
+$strGeneratePassword = 'Vytvoit heslo';
+$strGenerate = 'Vytvoit';
 $strGenTime = 'Vygenerovno';
 $strGeorgian = 'Gruzntina';
 $strGerman = 'Nmecky';
@@ -461,7 +465,7 @@ $strNoOptions = 'Tento formt nem dn nastaven';
 $strNoPassword = 'dn heslo';
 $strNoPermission = 'Web server nem oprvnn uloit vpis do souboru %s.';
 $strNoPhp = 'Bez PHP kdu';
-$strNoPrivileges = 'Bez oprvnn';
+$strNoPrivileges = 'Nemte oprvnn';
 $strNoQuery = 'dn SQL dotaz!';
 $strNoRights = 'Nemte dostaten prva na proveden tto akce!';
 $strNoRowsSelected = 'Nebyl vybrn dn dek';
@@ -524,13 +528,19 @@ $strPrintViewFull = 'Nhled k vytitn (s&nbsp;kompletnmi texty)';
 $strPrintView = 'Nhled k vytitn';
 $strPrint = 'Vytisknout';
 $strPrivDescAllPrivileges = 'Vechna oprvnn krom GRANT.';
+$strPrivDescAlterDb = 'Umouje mnit strukturu existujcch tabulek a vchoz znakov sady a azen databz.';
+$strPrivDescAlterRoutine = 'Umouje mnit a ruit uloen procedury.';
 $strPrivDescAlter = 'Umouje mnit strukturu existujcch tabulek.';
 $strPrivDescCreateDb = 'Umouje vytvet nov databze a tabulky.';
+$strPrivDescCreateRoutine = 'Umouje vytvet uloen procedury.';
 $strPrivDescCreateTbl = 'Umouje vytvet nov tabulky.';
 $strPrivDescCreateTmpTable = 'Umouje vytvet doasn tabulky.';
+$strPrivDescCreateUser = 'Umouje vytvet, ruit a pejmenovvat ty uivatel.';
+$strPrivDescCreateView = 'Umouje vytvet nov pohledy.';
 $strPrivDescDelete = 'Umouje mazat data.';
 $strPrivDescDropDb = 'Umouje odstranit databze a tabulky.';
 $strPrivDescDropTbl = 'Umouje odstranit tabulky.';
+$strPrivDescExecute5 = 'Umouje spoutt uloen procedury.';
 $strPrivDescExecute = 'Umouje spoutt uloen procedury. V&nbsp;tto verzi MySQL se nepouv.';
 $strPrivDescFile = 'Umouje importovat a exportovat data z/do soubor na serveru.';
 $strPrivDescGrant = 'Umouje pidvat uivatele a oprvnn bez znovunatn tabulek s&nbsp;oprvnnmi.';
@@ -548,6 +558,7 @@ $strPrivDescReplClient = 'Umon uivateli zjistit, kde je hlavn / pomocn server.';
 $strPrivDescReplSlave = 'Potebn pro replikaci pomocnch server.';
 $strPrivDescSelect = 'Umouje vybrat data.';
 $strPrivDescShowDb = 'Umouje pstup k&nbsp;plnmu seznamu databz.';
+$strPrivDescShowView = 'Umouje sputn dotazu SHOW CREATE VIEW.';
 $strPrivDescShutdown = 'Umouje vypnout server.';
 $strPrivDescSuper = 'Umouje pipojen, i kdy je dosaen maximln poet pipojen. Potebn pro vtinu operac pro sprvu serveru jako nastavovn globlnch promnnch a zabjen thread jinch uivatel.';
 $strPrivDescUpdate = 'Umouje mnit data.';
@@ -597,6 +608,7 @@ $strRevokeAndDelete = 'Odebrat uivatelm veker oprvnn a pot je odstranit z tabule
 $strRevokeMessage = 'Byla zruena prva pro %s';
 $strRevoke = 'Zruit';
 $strRomanian = 'Rumuntina';
+$strRoutines = 'Procedury';
 $strRowLength = 'Dlka dku';
 $strRowsFrom = 'dk zanajc od';
 $strRowSize = ' Velikost dku ';
@@ -661,6 +673,7 @@ $strSingly = '(po jednom)';
 $strSize = 'Velikost';
 $strSlovak = 'Sloventina';
 $strSlovenian = 'Slovintina';
+$strSocketProblem = '(nebo nen spvn nastaven lokln socket MySQL serveru)';
 $strSortByKey = 'Setdit podle kle';
 $strSort = 'adit';
 $strSpaceUsage = 'Vyuit msta';
@@ -730,6 +743,7 @@ $strTraditionalChinese = 'Tradin ntina';
 $strTraditionalSpanish = 'Tradin panltina';
 $strTraffic = 'Provoz';
 $strTransformation_application_octetstream__download = 'Zobraz odkaz na sthnut dat. Prvn parametr je jmno souboru, druh jmno sloupce v tabulce obsahujc jmno souboru. Pokud zadte druh parametr, prvn mus bt przdn.';
+$strTransformation_application_octetstream__hex = 'Zobraz data estnctkov.';
 $strTransformation_image_jpeg__inline = 'Zobraz nhled obrzku s&nbsp;odkazem na obrzek; parametry ka a vka v&nbsp;bodech (pomr stran obrzku zstane zachovn)';
 $strTransformation_image_jpeg__link = 'Zobraz odkaz na obrzek (napklad sthnut pole blob).';
 $strTransformation_image_png__inline = 'Viz image/jpeg: inline';
@@ -800,5 +814,4 @@ $strYes = 'Ano';
 $strZeroRemovesTheLimit = 'Poznmka: Nastaven tchto parametr na 0 (nulu) odstran omezen.';
 $strZip = '"zazipovno"';
 
-$strSocketProblem = '(or the local MySQL server\'s socket is not correctly configured)';  //to translate
 ?>
