@@ -1,5 +1,5 @@
 <?php
-/* $Id: tbl_properties_structure.php,v 2.35.2.1 2005/04/26 16:00:57 lem9 Exp $ */
+/* $Id: tbl_properties_structure.php,v 2.37.2.1 2005/06/30 17:20:26 lem9 Exp $ */
 // vim: expandtab sw=4 ts=4 sts=4:
 
 require_once('./libraries/grab_globals.lib.php');
@@ -198,7 +198,7 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         $zerofill     = stristr($row['Type'], 'zerofill');
     }
 
-    // rabus: Devide charset from the rest of the type definition (MySQL >= 4.1)
+    // rabus: Divide charset from the rest of the type definition (MySQL >= 4.1)
     unset($field_charset);
     if (PMA_MYSQL_INT_VERSION >= 40100) {
         if ((substr($type, 0, 4) == 'char'
@@ -247,6 +247,14 @@ while ($row = PMA_DBI_fetch_assoc($fields_rs)) {
         $attribute = 'ON UPDATE CURRENT_TIMESTAMP';
     }
 
+    // here, we have a TIMESTAMP that SHOW FULL FIELDS reports as having the 
+    // NULL attribute, but SHOW CREATE TABLE says the contrary. Believe
+    // the latter.
+    if (!empty($analyzed_sql[0]['create_table_fields'][$row['Field']]['type']) && $analyzed_sql[0]['create_table_fields'][$row['Field']]['type'] == 'TIMESTAMP' && $analyzed_sql[0]['create_table_fields'][$row['Field']]['timestamp_not_null']) {
+        $row['Null'] = '';
+    }
+
+
     if (!isset($row['Default'])) {
         if ($row['Null'] == 'YES') {
             $row['Default'] = '<i>NULL</i>';
